@@ -41,10 +41,8 @@
 #include "panel-util.h"
 #include "panel.h"
 #include "menu.h"
-#include "applet.h"
-#include "panel-config-global.h"
-#include "panel-profile.h"
 #include "panel-properties-dialog.h"
+#include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-addto.h"
 #include "panel-icon-names.h"
@@ -52,13 +50,13 @@
 static void
 panel_context_menu_create_new_panel (GtkWidget *menuitem)
 {
-	panel_profile_create_toplevel (gtk_widget_get_screen (menuitem));
+	panel_layout_toplevel_create (gtk_widget_get_screen (menuitem));
 }
 
 static void
 panel_context_menu_delete_panel (PanelToplevel *toplevel)
 {
-	if (panel_toplevel_is_last_unattached (toplevel)) {
+	if (panel_toplevel_is_last (toplevel)) {
 		panel_error_dialog (GTK_WINDOW (toplevel),
 				    gtk_window_get_screen (GTK_WINDOW (toplevel)),
 				    "cannot_delete_last_panel", TRUE,
@@ -107,9 +105,9 @@ panel_context_menu_setup_delete_panel_item (GtkWidget *menu,
 	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
 
 	sensitive =
-		!panel_toplevel_is_last_unattached (panel_widget->toplevel) &&
-		!panel_lockdown_get_locked_down () &&
-		panel_profile_id_lists_are_writable ();
+		!panel_toplevel_is_last (panel_widget->toplevel) &&
+		!panel_lockdown_get_panels_locked_down_s () &&
+		panel_layout_is_writable ();
 
 	gtk_widget_set_sensitive (menuitem, sensitive);
 }
@@ -129,7 +127,7 @@ panel_context_menu_build_edition (PanelWidget *panel_widget,
         g_signal_connect (G_OBJECT (menuitem), "activate",
 	      	       	  G_CALLBACK (panel_addto_present), panel_widget);
 
-	if (!panel_profile_id_lists_are_writable ())
+	if (!panel_layout_is_writable ())
 		gtk_widget_set_sensitive (menuitem, FALSE);
 
 	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Properties"));
@@ -166,7 +164,7 @@ panel_context_menu_build_edition (PanelWidget *panel_widget,
 			  G_CALLBACK (panel_context_menu_create_new_panel), 
 			  NULL);
 	gtk_widget_set_sensitive (menuitem, 
-				  panel_profile_id_lists_are_writable ());
+				  panel_layout_is_writable ());
 }
 
 GtkWidget *
@@ -174,23 +172,11 @@ panel_context_menu_create (PanelWidget *panel)
 {
 	GtkWidget *retval;
 
-	if (panel->master_widget) {
-		gpointer    *pointer;
-		AppletInfo  *info;
-
-		pointer = g_object_get_data (G_OBJECT (panel->master_widget),
-					     "applet_info");
-
-		g_assert (pointer != NULL);
-		info = (AppletInfo *) pointer;
-
-		return panel_applet_get_menu (info);
-	}
-
-	if (panel_lockdown_get_locked_down ())
+	if (panel_lockdown_get_panels_locked_down_s ())
 		return NULL;
 
 	retval = create_empty_menu ();
+
 	gtk_widget_set_name (retval, "gnome-panel-context-menu");
 
 	panel_context_menu_build_edition (panel, retval);
