@@ -37,12 +37,11 @@
 #include "applet.h"
 #include "xstuff.h"
 #include "panel-bindings.h"
-#include "panel-config-global.h"
 #include "panel-gconf.h"
 #include "panel-globals.h"
 #include "launcher.h"
 #include "panel-icon-names.h"
-#include "panel-lockdown.h"
+#include "panel-schemas.h"
 
 char *
 panel_util_make_exec_uri_for_desktop (const char *exec)
@@ -334,140 +333,11 @@ panel_load_icon (GtkIconTheme  *icon_theme,
 	return retval;
 }
 
-static char *
-panel_lock_screen_action_get_command (const char *action)
-{
-	char    *command          = NULL;
-	gboolean use_gscreensaver = FALSE;
-
-	if (panel_is_program_in_path ("gnome-screensaver-command")
-	    && panel_is_program_in_path ("gnome-screensaver-preferences"))
-		use_gscreensaver = TRUE;
-	else if (!panel_is_program_in_path ("xscreensaver-command"))
-		return NULL;
-
-	if (strcmp (action, "prefs") == 0) {
-		if (use_gscreensaver) {
-			command = g_strdup ("gnome-screensaver-preferences");
-		} else if (panel_is_program_in_path ("xscreensaver-demo")) {
-			command = g_strdup ("xscreensaver-demo");
-		} else {
-			command = NULL;
-		}
-	} else if (strcmp (action, "activate") == 0
-		   || strcmp (action, "lock") == 0) {
-		/* Neither gnome-screensaver or xscreensaver allow root
-		 * to lock the screen */
-		if (geteuid () == 0) {
-			command = NULL;
-		} else {
-			if (use_gscreensaver) {
-				command = g_strdup_printf ("gnome-screensaver-command --%s", action);
-			} else {
-				command = g_strdup_printf ("xscreensaver-command -%s", action);
-			}
-		}
-	}
-
-	return command;
-}
-
-gboolean
-panel_lock_screen_action_available (const char *action)
-{
-	char    *command;
-	gboolean enabled = FALSE;
-
-	g_return_val_if_fail (action != NULL, FALSE);
-
-	if (strcmp (action, "prefs") != 0 &&
-	    panel_lockdown_get_disable_lock_screen ())
-		return FALSE;
-
-	command = panel_lock_screen_action_get_command (action);
-	if (command)
-		enabled = TRUE;
-
-	g_free (command);
-
-	return enabled;
-}
-
-void
-panel_lock_screen_action (GdkScreen  *screen,
-			  const char *action)
-{
-	GError  *error            = NULL;
-	char    *command          = NULL;
-	GdkAppLaunchContext *launch_context = NULL;
-	GAppInfo            *app_info = NULL;
-	GdkDisplay          *display;
-
-	g_return_if_fail (GDK_IS_SCREEN (screen));
-	g_return_if_fail (action != NULL);
-
-	if (strcmp (action, "prefs") != 0 &&
-	    panel_lockdown_get_disable_lock_screen ())
-		return;
-
-	command = panel_lock_screen_action_get_command (action);
-
-	if (!command)
-		return;
-
-	app_info = g_app_info_create_from_commandline (command,
-						       NULL,
-						       G_APP_INFO_CREATE_NONE,
-						       &error);
-
-	if (!error) {
-		display = gdk_screen_get_display (screen);
-		launch_context = gdk_display_get_app_launch_context (display);
-		gdk_app_launch_context_set_screen (launch_context, screen);
-		g_app_info_launch (app_info, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error);
-
-		g_object_unref (launch_context);
-	}
-
-	/* error either by create or launch the command */
-	if (error) {
-		char *primary;
-
-		primary = g_strdup_printf (_("Could not execute '%s'"),
-					   command);
-		panel_error_dialog (NULL, screen,
-				    "cannot_exec_screensaver", TRUE,
-				    primary, error->message);
-		g_free (primary);
-		g_error_free (error);
-	}
-
-	g_free (command);
-	g_object_unref (app_info);
-}
-
-void
-panel_lock_screen (GdkScreen *screen)
-{
-	panel_lock_screen_action (screen, "lock");
-}
-
-
-#define PANEL_LAUNCHER_PERSONAL_PATH "panel2.d/default/launchers"
-
 static char *
 panel_launcher_get_personal_path (void)
 {
-        const char *override;
-
-        override = g_getenv ("GNOME22_USER_DIR");
-
-        if (override)
-               return g_build_filename (override,
-                                        PANEL_LAUNCHER_PERSONAL_PATH, NULL);
-        else
-                return g_build_filename (g_get_home_dir (), ".gnome2",
-                                         PANEL_LAUNCHER_PERSONAL_PATH, NULL);
+	return g_build_filename (g_get_user_config_dir (),
+				 "gnome-panel", "launchers", NULL);
 }
 
 gboolean
@@ -1170,7 +1040,15 @@ panel_util_query_tooltip_cb (GtkWidget  *widget,
 			     GtkTooltip *tooltip,
 			     const char *text)
 {
-	if (!panel_global_config_get_tooltips_enabled ())
+	GSettings *gsettings;
+	gboolean   enable_tooltips;
+
+	gsettings = g_settings_new (PANEL_GENERAL_SCHEMA);
+	enable_tooltips = g_settings_get_boolean (gsettings,
+						  PANEL_GENERAL_ENABLE_TOOLTIPS_KEY);
+	g_object_unref (gsettings);
+
+	if (!enable_tooltips)
 		return FALSE;
 
 	gtk_tooltip_set_text (tooltip, text);
@@ -1298,3 +1176,21 @@ panel_util_key_event_is_popup_panel (GdkEventKey *event,
 	panel_util_key_event_is_binding (event, PANEL_TYPE_TOPLEVEL, "popup-panel-menu",
 					 is_popup, is_popup_modifier);
 }
+
+char *
+panel_util_get_user_name (void)
+{
+	char *name;
+
+	name = g_locale_to_utf8 (g_get_real_name (), -1, NULL, NULL, NULL);
+
+	if (PANEL_GLIB_STR_EMPTY (name) || g_strcmp0 (name, "Unknown") == 0) {
+		g_free (name);
+		name = g_locale_to_utf8 (g_get_user_name (), -1 , NULL, NULL, NULL);
+	}
+
+	if (!name)
+		name = g_strdup (g_get_user_name ());
+
+	return name;
+}
