@@ -27,8 +27,6 @@ G_BEGIN_DECLS
 
 #define PANEL_MINIMUM_WIDTH 12
 
-#define PANEL_APPLET_ASSOC_PANEL_KEY "panel_applet_assoc_panel_key"
-#define PANEL_APPLET_FORBIDDEN_PANELS "panel_applet_forbidden_panels"
 #define PANEL_APPLET_DATA "panel_applet_data"
 
 #ifndef TYPEDEF_PANEL_WIDGET
@@ -58,14 +56,16 @@ struct _AppletSizeHintsAlloc {
 struct _AppletData
 {
 	GtkWidget *	applet;
-	int		pos;
+
+	PanelObjectPackType pack_type;
+	int		    pack_index;
+
+	/* constrained position from the left, after taking other objects into
+	 * account */
 	int             constrained;
 	int		cells;
 	int             min_cells;
 
-	int		drag_off; /* offset on the applet where drag
-				     was started */
-
 	int		no_die; /* if >0 never send the about to die
 				   signal, an int and not a bool for
 				   nesting reasons */
@@ -77,8 +77,6 @@ struct _AppletData
 	guint           size_constrained : 1;
 	guint           expand_major : 1;
 	guint           expand_minor : 1;
-	guint           locked : 1;
-  
 };
 
 struct _PanelWidget
@@ -94,13 +92,12 @@ struct _PanelWidget
 	int             sz;
 
 	AppletData     *currently_dragged_applet;
+	guint           dragged_state;
 
 	int             thick;
 
 	PanelBackground background;
 
-	GtkWidget      *master_widget;
-	
 	GtkWidget      *drop_widget;     /* widget that the panel checks for
 	                                  * the cursor on drops usually the
 	                                  * panel widget itself
@@ -135,8 +132,6 @@ struct _PanelWidgetClass
                             GtkDirectionType	 dir);
 	void (* switch_move) (PanelWidget	*panel,
                               GtkDirectionType	 dir);
-	void (* free_move) (PanelWidget		*panel,
-                            GtkDirectionType	 dir);
 	void (* tab_move) (PanelWidget	*panel,
                            gboolean	 next);
 	void (* end_move) (PanelWidget	*panel);
@@ -148,32 +143,25 @@ GtkWidget *	panel_widget_new		(PanelToplevel  *toplevel,
 						 gboolean        packed,
 						 GtkOrientation  orient,
 						 int             sz);
-/*add an applet to the panel, preferably at position pos, if insert_at_pos
-  is on, we REALLY want to insert at the pos given by pos*/
-int		panel_widget_add		(PanelWidget *panel,
-						 GtkWidget   *applet,
-						 gboolean     locked,
-						 int          pos,
-						 gboolean     insert_at_pos);
-
-/*needs to be called for drawers after add*/
-void		panel_widget_add_forbidden	(PanelWidget *panel);
+/* add an applet to the panel; if use_pack_index is FALSE, pack_index is ignored
+ * and the applet is appended at the end of the pack list for pack_style */
+void		panel_widget_add		(PanelWidget         *panel,
+						 GtkWidget           *applet,
+						 PanelObjectPackType  pack_style,
+						 int                  pack_index,
+						 gboolean             use_pack_index);
 
 /*move applet to a different panel*/
-int		panel_widget_reparent		(PanelWidget *old_panel,
-						 PanelWidget *new_panel,
-						 GtkWidget *applet,
-						 int pos);
-
-/* use these for drag_off for special cases */
-#define PW_DRAG_OFF_CURSOR -1
-#define PW_DRAG_OFF_CENTER -2
+int		panel_widget_reparent		(PanelWidget         *old_panel,
+						 PanelWidget         *new_panel,
+						 GtkWidget           *applet,
+						 PanelObjectPackType  pack_type,
+						 int                  pack_index);
 
 /*drag*/
 gboolean        panel_applet_is_in_drag         (void);
 void		panel_widget_applet_drag_start	(PanelWidget *panel,
 						 GtkWidget   *applet,
-						 int          drag_off,
 						 guint32      time_);
 void		panel_widget_applet_drag_end	(PanelWidget *panel);
 
@@ -192,11 +180,17 @@ void		panel_widget_draw_icon		(PanelWidget *panel,
 						 ButtonWidget *applet);
 
 
-/*tells us if an applet is "stuck" on the right side*/
-int		panel_widget_is_applet_stuck	(PanelWidget *panel,
-						 GtkWidget *applet);
 /*get pos of the cursor location in panel coordinates*/
 int		panel_widget_get_cursorloc	(PanelWidget *panel);
+/* get pack type & index for insertion at the cursor location in panel */
+void            panel_widget_get_insert_at_cursor (PanelWidget         *widget,
+						   PanelObjectPackType *pack_type,
+						   int                 *pack_index);
+/* get pack type for insertion at the cursor location in panel */
+PanelObjectPackType panel_widget_get_insert_pack_type_at_cursor (PanelWidget *panel);
+/* get index for insertion with pack type */
+int                 panel_widget_get_new_pack_index   (PanelWidget          *panel,
+						       PanelObjectPackType   pack_type);
 
 /*needed for other panel types*/
 gboolean	panel_widget_is_cursor		(PanelWidget *panel,
@@ -219,14 +213,6 @@ void     panel_widget_set_applet_size_hints       (PanelWidget *panel,
 						   int         *size_hints,
 						   int          size_hints_len);
 
-void     panel_widget_set_applet_locked           (PanelWidget *panel,
-						   GtkWidget   *applet,
-						   gboolean     locked);
-gboolean panel_widget_get_applet_locked           (PanelWidget *panel,
-						   GtkWidget   *applet);
-gboolean panel_widget_toggle_applet_locked        (PanelWidget *panel,
-						   GtkWidget   *applet);
-
 void     panel_widget_register_open_dialog        (PanelWidget *panel,
 						   GtkWidget   *dialog);  
 G_END_DECLS
